@@ -19,13 +19,15 @@ from tempfile import _TemporaryFileWrapper as TemporaryFileWrapperBase
 from clu.constants.consts import λ, DELETE_FLAG, ENCODING, PATH, SCRIPT_PATH
 from clu.constants.exceptions import ExecutionError, FilesystemError
 from clu.constants.polyfills import lru_cache, scandir, walk
+from clu.abstract import ValueDescriptor
 from clu.dicts import OrderedItemsView, OrderedKeysView, OrderedValuesView
 from clu.predicates import attr, allattrs, anyof
+from clu.repr import stringify
 from clu.sanitizer import utf8_encode
 from clu.typology import isnotpath, isvalidpath
 from clu.fs.misc import differentfile, filesize, gethomedir, masked_permissions
-from clu.fs.misc import stringify, suffix_searcher, swapext, u8str
-from clu.exporting import ValueDescriptor, Exporter
+from clu.fs.misc import suffix_searcher, swapext, u8str
+from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
@@ -587,6 +589,16 @@ class TemporaryName(collections.abc.Hashable,
                                 follow_symlinks=True))
         return False
     
+    def parent(self):
+        """ Sugar for `os.path.abspath(os.path.join(self.name, os.pardir))`
+            which, if you are curious, gets you the parent directory of
+            the instances’ target filename, wrapped in a Directory
+            instance.
+        """
+        return self.directory(os.path.abspath(
+                              os.path.join(self.name,
+                                           os.pardir)))
+    
     def read(self, *, original_position=False):
         """ Read data from the temporary name, if it points to an existing file """
         orig, out = 0, b""
@@ -603,7 +615,7 @@ class TemporaryName(collections.abc.Hashable,
     
     def write(self, data):
         """ Write data to the temporary name using a context-managed handle """
-        ensure_path_is_valid(self._name)
+        assert self.exists or self.parent().exists
         bytestring = utf8_encode(data)
         with open(self._name, "xb") as handle:
             handle.write(bytestring)
@@ -620,16 +632,6 @@ class TemporaryName(collections.abc.Hashable,
         self._destroy = False
         return self._name
     
-    def parent(self):
-        """ Sugar for `os.path.abspath(os.path.join(self.name, os.pardir))`
-            which, if you are curious, gets you the parent directory of
-            the instances’ target filename, wrapped in a Directory
-            instance.
-        """
-        return self.directory(os.path.abspath(
-                              os.path.join(self.name,
-                                           os.pardir)))
-    
     def close(self):
         """ Destroys any existing file at this instances’ file path. """
         if self.exists:
@@ -1038,6 +1040,8 @@ class Directory(collections.abc.Hashable,
            `os.fspath(…)`. Internally, this method uses `shutil.copy2(…)`
             to tell the filesystem to copy and rename each file in succession.
         """
+        if destination is None:
+            raise FilesystemError("“flatten(…)” destination path cannot be None")
         whereto = self.directory(pth=destination)
         if anyof(whereto.exists, os.path.isfile(whereto.name),
                                  os.path.islink(whereto.name)):
@@ -1085,6 +1089,8 @@ class Directory(collections.abc.Hashable,
            `os.fspath(…)`. Internally, this method uses `shutil.copytree(…)`
             to tell the filesystem what to copy where.
         """
+        if destination is None:
+            raise FilesystemError("“copy_all(…)” destination path cannot be None")
         whereto = self.directory(pth=destination)
         if anyof(whereto.exists, os.path.isfile(whereto.name),
                                  os.path.islink(whereto.name)):
@@ -1139,7 +1145,7 @@ class Directory(collections.abc.Hashable,
             or anything with an `__fspath__(…)` method. 
         """
         if destination is None:
-            raise FilesystemError("symlink destination cannot be None")
+            raise FilesystemError("“symlink(…)” destination path cannot be None")
         os.symlink(os.fspath(source or self.name),
                    os.fspath(destination),
                    target_is_directory=True)
